part of 'change_pass_cubit.dart';

abstract class ChangePassState extends Equatable{
  const ChangePassState();
  @override
  List<Object> get props => [];
}
class ChangePassInitial extends ChangePassState {}
class ValidateCurrentPasswordError extends ChangePassState {
  final String? error;

  ValidateCurrentPasswordError(this.error);

  @override
  String toString() => 'ValidateCurrentPasswordError { error: $error }';
}
class ChangePassLoading extends ChangePassState {
  ChangePassLoading();
  @override
  String toString() => 'ChangePassLoading';
}
class ChangePassFailure extends ChangePassState {
  final String error;

  ChangePassFailure(this.error);

  @override
  String toString() => 'ChangePassFailure { error: $error }';
}
class ValidateRePasswordError extends ChangePassState {
  final String error;

  ValidateRePasswordError(this.error);

  @override
  String toString() => 'ValidateRePasswordError { error: $error }';
}
class ValidateNewPasswordError extends ChangePassState {
  final String error;

  ValidateNewPasswordError(this.error);

  @override
  String toString() => 'ValidateNewPasswordError { error: $error }';
}
class ChangePassSuccess extends ChangePassState {
  final String msg;

  ChangePassSuccess(this.msg);

  @override
  String toString() => 'ChangePassSuccess{msg: $msg}';
}
